"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AbstractParseTreeVisitor_1 = require("antlr4ts/tree/AbstractParseTreeVisitor");
const ast_nodes_1 = require("../ast-nodes");
const SECONDS = 1;
const MINUTES = SECONDS * 60;
const HOURS = MINUTES * 60;
const DAYS = HOURS * 24;
const WEEKS = DAYS * 7;
class RDFFunctionFactory extends AbstractParseTreeVisitor_1.AbstractParseTreeVisitor {
    constructor(now) {
        super();
        this.nowCache = now || Math.floor(+new Date / 1000);
    }
    now() {
        return this.nowCache;
    }
    defaultResult() {
        return new ast_nodes_1.NullNode();
    }
    visitRangeDirective(ctx) {
        return new ast_nodes_1.RangeNode(this.visit(ctx._begin), this.visit(ctx._end));
    }
    visitTrailDirective(ctx) {
        return new ast_nodes_1.TrailNode(this.visit(ctx._end), this.visit(ctx._period));
    }
    visitPeriodDirective(ctx) {
        var ref;
        if (ctx._ref) {
            ref = this.visit(ctx._ref);
        }
        else {
            ref = new ast_nodes_1.RelativeExpressionNode(new ast_nodes_1.TimestampNode(this.now()));
        }
        return new ast_nodes_1.PeriodNode(this.visit(ctx._begin), this.visit(ctx._period), ref);
    }
    visitResolvableExpression(ctx) {
        var staticTime;
        if (ctx.staticExpression()) {
            staticTime = this.visit(ctx.staticExpression());
        }
        else {
            staticTime = this.visit(ctx.staticPeriod());
        }
        var relPeriod = undefined;
        if (ctx.relativePeriod()) {
            relPeriod = this.visit(ctx.relativePeriod());
        }
        return new ast_nodes_1.RelativeExpressionNode(staticTime, relPeriod);
    }
    visitStaticExpression(ctx) {
        var timestamp;
        if (ctx._first) {
            var acc = 0;
            for (var context of ctx._then) {
                acc += this.visit(context).solve();
            }
            timestamp = this.visit(ctx._first).solve() + acc;
        }
        else {
            timestamp = this.solveStaticExpression(ctx.payload.text);
        }
        return new ast_nodes_1.TimestampNode(timestamp);
    }
    solveStaticExpression(expr) {
        if (expr == "now") {
            return this.now();
        }
        else {
            return parseFloat(expr);
        }
    }
    visitRelativePeriod(ctx) {
        var token = this.visit(ctx.relativeIdentifier()).solve();
        var quantity;
        if (ctx.unaryExpr()) {
            quantity = this.visit(ctx.unaryExpr()).solve();
        }
        else {
            quantity = parseInt(ctx.NUMBER().payload.text);
        }
        return new ast_nodes_1.RelativeTokenNode(token, quantity);
    }
    visitStaticPeriod(ctx) {
        var token = this.visit(ctx.staticIdentifier()).solve();
        var quantity;
        if (ctx.unaryExpr()) {
            quantity = this.visit(ctx.unaryExpr()).solve();
        }
        else {
            quantity = parseInt(ctx.NUMBER().payload.text);
        }
        var period;
        switch (token) {
            case 's':
                period = quantity * SECONDS;
                break;
            case 'm':
                period = quantity * MINUTES;
                break;
            case 'h':
                period = quantity * HOURS;
                break;
            case 'd':
                period = quantity * DAYS;
                break;
            case 'w':
                period = quantity * WEEKS;
            default:
                throw new Error(`Static token type ${token} is not recognized`);
        }
        return new ast_nodes_1.NumberNode(period);
    }
    visitNegUnaryExpr(ctx) {
        return new ast_nodes_1.NumberNode(-1 * parseInt(ctx.NUMBER().payload.text));
    }
    visitPosUnaryExpr(ctx) {
        return new ast_nodes_1.NumberNode(parseInt(ctx.NUMBER().payload.text));
    }
    visitRelativeIdentifier(ctx) {
        return new ast_nodes_1.StringNode(ctx.payload.text);
    }
    visitStaticIdentifier(ctx) {
        return new ast_nodes_1.StringNode(ctx.payload.text);
    }
}
exports.RDFFunctionFactory = RDFFunctionFactory;
