"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha");
const chai_1 = require("chai");
const RelativeDateFormatLexer_1 = require("../lib/lexer-parser/RelativeDateFormatLexer");
const helpers_1 = require("./helpers");
describe("Tokenization tests", function () {
    var passing_runs = [
        {
            rdf: "$range$",
            desc: "range token",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$trail$",
            desc: "trail token",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.TRAIL,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$period$",
            desc: "period token",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.PERIOD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0$0$",
            desc: "epoch to epoch",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$1020$174398127390$",
            desc: "long numbers",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0$now$",
            desc: "epoch to now",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NOW,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$now$now$",
            desc: "now to now",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NOW,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NOW,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1s$0+1s$",
            desc: "second offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1m$0+1m$",
            desc: "minute offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MINUTES,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MINUTES,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1h$0+1h$",
            desc: "hour offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.HOURS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.HOURS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1d$0+1d$",
            desc: "day offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.DAYS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.DAYS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1w$0+1w$",
            desc: "week offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.WEEKS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.WEEKS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1M$0+1M$",
            desc: "month offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MONTHS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MONTHS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1Q$0+1Q$",
            desc: "quarter offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.QUARTERS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.QUARTERS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1Y$0+1Y$",
            desc: "year offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.YEARS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.YEARS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1s+1m$0+1s-1m$",
            desc: "composite static offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MINUTES,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MINUTES,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        },
        {
            rdf: "$range$0-1s+1M$0+1s-1M$",
            desc: "composite static/relative offsets",
            tokens: [
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.RANGE,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MONTHS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_ADD,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SECONDS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.OP_MIN,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.NUMBER,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.MONTHS,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.SEPERATOR,
                RelativeDateFormatLexer_1.RelativeDateFormatLexer.EOF
            ]
        }
    ];
    for (let run of passing_runs) {
        it(`${run.rdf.replace(/\n/g, "\\n")}: ${run.desc} should tokenize`, function () {
            chai_1.expect(helpers_1.getTokenListFromString(run.rdf)).to.be.eql(run.tokens);
        });
    }
});
