grammar RelativeDateFormat;

directive
  : SEPERATOR RANGE SEPERATOR begin=resolvableExpression SEPERATOR end=resolvableExpression SEPERATOR #RangeDirective
  | SEPERATOR TRAIL SEPERATOR end=resolvableExpression SEPERATOR (period=relativeExpression) SEPERATOR #TrailDirective
  | SEPERATOR PERIOD SEPERATOR begin=resolvableExpression SEPERATOR (period=relativeExpression) SEPERATOR (ref=resolvableExpression SEPERATOR)? #PeriodDirective
  ;

relativeExpression
  : (resolvableExpression|relativePeriod);

resolvableExpression
  : (staticPeriod|staticExpression) rel=relativePeriod?;

staticExpression
  : (timestamp | NOW)
  | first=staticExpression (then+=staticPeriod)+
  ;

staticPeriod
  : unaryExpr staticIdentifier
  | NUMBER staticIdentifier;

relativePeriod
  : unaryExpr relativeIdentifier
  | NUMBER relativeIdentifier;

unaryExpr
  : OP_ADD NUMBER #posUnaryExpr
  | OP_MIN NUMBER #negUnaryExpr
  ;

staticIdentifier
  : SECONDS
  | MINUTES
  | HOURS
  | DAYS
  | WEEKS;

relativeIdentifier
  : MONTHS
  | QUARTERS
  | YEARS;

handler
  : RANGE
  | TRAIL
  | PERIOD;

timestamp
  : (NUMBER)+;

NOW
  : 'now';

SECONDS
  : 's';

MINUTES
  : 'm';

HOURS
  : 'h';

DAYS
  : 'd';

WEEKS
  : 'w';

MONTHS
  : 'M';

QUARTERS
  : 'Q';

YEARS
  : 'Y';

RANGE
  : 'range';

TRAIL
  : 'trail';

PERIOD
  : 'period';

OP_MIN
  : '-';

OP_ADD
  : '+';

NUMBER
  : [0-9]+;

SEPERATOR
  : '$';

// ignore all whitespace
WS
  : [ \r\n\t] + -> skip;






